==> zzyj-outputvalcount-impl-3.0.0-20220513.091739-11-sources.jar: com/ejianc/business/outputvalcount/bean/XmyxglEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目影像管理
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_xmyxgl")
public class XmyxglEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="xm_id")
    private Long xmId; // 项目id
    @TableField(value="xm_name")
    private String xmName; // 项目名称
    @TableField(value="sgdw_id")
    private Long sgdwId; // 施工单位id
    @TableField(value="sgdw_name")
    private String sgdwName; // 施工单位
    @TableField(value="yxmc")
    private String yxmc; // 影像名称
    @TableField(value="gclx")
    private Integer gclx; // 工程类型(1线性工程，2群体工程、3单体工程、4其他)
    @TableField(value="ssxjz_id")
    private Long ssxjzId; // 所属巡检组id
    @TableField(value="ssxjz_name")
    private String ssxjzName; // 所属巡检组
    @TableField(value="psrq")
    private Date psrq; // 拍摄日期
    @TableField(value="pssm")
    private String pssm; // 拍摄说明
    @TableField(value="syxs")
    private Integer syxs; // 是否显示在首页（1否，2是）


    public Integer getSyxs() {
        return syxs;
    }

    public void setSyxs(Integer syxs) {
        this.syxs = syxs;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getXmId() {
        return xmId;
    }

    public void setXmId(Long xmId) {
        this.xmId = xmId;
    }
    public String getXmName() {
        return xmName;
    }

    public void setXmName(String xmName) {
        this.xmName = xmName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public String getYxmc() {
        return yxmc;
    }

    public void setYxmc(String yxmc) {
        this.yxmc = yxmc;
    }
    public Integer getGclx() {
        return gclx;
    }

    public void setGclx(Integer gclx) {
        this.gclx = gclx;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getPsrq() {
        return psrq;
    }

    public void setPsrq(Date psrq) {
        this.psrq = psrq;
    }
    public String getPssm() {
        return pssm;
    }

    public void setPssm(String pssm) {
        this.pssm = pssm;
    }

    
}

==> zzyj-outputvalcount-impl-3.0.0-20221206.081949-132-sources.jar: com/ejianc/business/outputvalcount/bean/XmyxglEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目影像管理
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_xmyxgl")
public class XmyxglEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="xm_id")
    private Long xmId; // 项目id
    @TableField(value="xm_name")
    private String xmName; // 项目名称
    @TableField(value="sgdw_id")
    private Long sgdwId; // 施工单位id
    @TableField(value="sgdw_name")
    private String sgdwName; // 施工单位
    @TableField(value="yxmc")
    private String yxmc; // 影像名称
    @TableField(value="gclx")
    private Integer gclx; // 工程类型(1线性工程，2群体工程、3单体工程、4其他)
    @TableField(value="ssxjz_id")
    private Long ssxjzId; // 所属巡检组id
    @TableField(value="ssxjz_name")
    private String ssxjzName; // 所属巡检组
    @TableField(value="psrq")
    private Date psrq; // 拍摄日期
    @TableField(value="pssm")
    private String pssm; // 拍摄说明
    @TableField(value="syxs")
    private Integer syxs; // 是否显示在首页（1否，2是）
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目组织id

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public Integer getSyxs() {
        return syxs;
    }

    public void setSyxs(Integer syxs) {
        this.syxs = syxs;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getXmId() {
        return xmId;
    }

    public void setXmId(Long xmId) {
        this.xmId = xmId;
    }
    public String getXmName() {
        return xmName;
    }

    public void setXmName(String xmName) {
        this.xmName = xmName;
    }
    public Long getSgdwId() {
        return sgdwId;
    }

    public void setSgdwId(Long sgdwId) {
        this.sgdwId = sgdwId;
    }
    public String getSgdwName() {
        return sgdwName;
    }

    public void setSgdwName(String sgdwName) {
        this.sgdwName = sgdwName;
    }
    public String getYxmc() {
        return yxmc;
    }

    public void setYxmc(String yxmc) {
        this.yxmc = yxmc;
    }
    public Integer getGclx() {
        return gclx;
    }

    public void setGclx(Integer gclx) {
        this.gclx = gclx;
    }
    public Long getSsxjzId() {
        return ssxjzId;
    }

    public void setSsxjzId(Long ssxjzId) {
        this.ssxjzId = ssxjzId;
    }
    public String getSsxjzName() {
        return ssxjzName;
    }

    public void setSsxjzName(String ssxjzName) {
        this.ssxjzName = ssxjzName;
    }
    public Date getPsrq() {
        return psrq;
    }

    public void setPsrq(Date psrq) {
        this.psrq = psrq;
    }
    public String getPssm() {
        return pssm;
    }

    public void setPssm(String pssm) {
        this.pssm = pssm;
    }

    
}
